@@ -224,9 +224,9 @@ class SendGrid(object):
     def del_category(self, category, name):
         return self.call('category', 'del', dict(category=category, name=name))
 
-    def get_category_stats(self, category, user, **fields):
+    def get_category_stats(self, category, user):
         '''other fields can be days, start_date, end_date'''
-        return self.call('stats', 'get', dict(category=category, user=user, **fields))
+        return self.call('stats', 'get', dict(category=category, user=user))
 
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
